@@ -6,7 +6,8 @@
   op.exuber <- list(
     exuber.show_progress = TRUE,
     exuber.parallel = TRUE,
-    exuber.ncores = ncores
+    exuber.ncores = ncores,
+    exuber.global_seed = NA
   )
   toset <- !(names(op.exuber) %in% names(op))
   if (any(toset)) options(op.exuber[toset])
@@ -17,7 +18,9 @@
 # Set Global Variables to avoid NOTES in cmdchecks
 if (getRversion() >= "2.15.1") {
   utils::globalVariables(
-    c("crit","i")
+    c("adf", "sadf", "gsadf", "badf", "bsadf", "bsadf_panel", "gsadf_panel",
+      "Distribution", ".", "crit", "i", "id", "name","sig", "key", "tstat",
+      "value", "value_x", "value_y", "stat", "pval")
   )
 }
 
