@@ -18,13 +18,16 @@ test_that("class checks", {
 })
 
 test_that("error diagnostics", {
-  expect_error(diagnostics(radf_div, mc), "Cannot reject H0")
-  expect_error(diagnostics(radf_95, mc),
-    "Cannot reject H0 for significance level 95%")
+  expect_message(print(
+    diagnostics(radf_div, mc)), "Cannot reject H0")
+  expect_message(
+    print(diagnostics(radf_95, mc)),
+    "Cannot reject H0 for significance level 95%"
+  )
 })
 
 test_that("different minw", {
-  msg <- "Different minimum window"
+  msg <- "minimum window does not match"
   expect_error(summary(radf_dta, mc2_minw20), msg)
   expect_error(diagnostics(radf_dta, mc2_minw20), msg)
   expect_error(datestamp(radf_dta, mc2_minw20), msg)
@@ -50,12 +53,14 @@ withr::with_options(
     expect_error(diagnostics(radf_dta, mc), regexp = NA)
     expect_error(diagnostics(radf_dta, mc, option = "sadf"), regexp = NA)
     expect_error(datestamp(radf_dta, mc), regexp = NA)
-    expect_error(datestamp(radf_dta, mc, min_duration = 50),
-                 "Argument 'min_duration' excludes all explosive periods")
+    expect_error(
+      datestamp(radf_dta, mc, min_duration = 50),
+      "Argument 'min_duration' excludes all explosive periods"
+    )
     expect_error(datestamp(radf_dta, mc, option = "sadf"), regexp = NA)
     expect_error(autoplot(radf_dta, mc), regexp = NA)
 
-# wokr here ---------------------------------------------------------------
+    # wokr here ---------------------------------------------------------------
 
     expect_error(autoplot(radf_dta, mc, option = "sadf"), regexp = NA)
   })
@@ -78,13 +83,12 @@ withr::with_options(
   c(warn = 2),
   test_that("no problem running summary (wb)", {
     expect_error(summary(radf_dta, wb), regexp = NA)
-    msg <- "'sadf' applies onyl to MC critical values"
     expect_error(diagnostics(radf_dta, wb), regexp = NA)
-    expect_error(diagnostics(radf_dta, wb, option = "sadf"), msg)
+    expect_error(diagnostics(radf_dta, wb, option = "sadf"), regexp = NA)
     expect_error(datestamp(radf_dta, wb), regexp = NA)
-    expect_error(datestamp(radf_dta, wb, option = "sadf"), msg)
+    expect_error(datestamp(radf_dta, wb, option = "sadf"), regexp = NA)
     expect_error(autoplot(radf_dta, wb), regexp = NA)
-    expect_error(autoplot(radf_dta, wb, option = "sadf"), msg)
+    expect_error(autoplot(radf_dta, wb, option = "sadf"), regexp = NA)
   })
 )
 
@@ -93,17 +97,16 @@ withr::with_options(
   test_that("no problem running summary (lag,wb)", {
     expect_error(summary(radf_dta_lag1, wb), regexp = NA)
     expect_error(diagnostics(radf_dta_lag1, wb), regexp = NA)
-    msg <- "'sadf' applies onyl to MC critical values"
-    expect_error(diagnostics(radf_dta_lag1, wb, option = "sadf"), msg)
+    expect_error(diagnostics(radf_dta_lag1, wb, option = "sadf"), regexp = NA)
     expect_error(datestamp(radf_dta_lag1, wb), regexp = NA)
-    expect_error(datestamp(radf_dta_lag1, wb, option = "sadf"), msg)
+    expect_error(datestamp(radf_dta_lag1, wb, option = "sadf"), regexp = NA)
     expect_error(autoplot(radf_dta_lag1, wb), regexp = NA)
-    expect_error(autoplot(radf_dta_lag1, wb, option = "sadf"), msg)
-    expect_error(autoplot(radf_dta_lag1, wb, plot_type = "single"), regexp = NA)
+    expect_error(autoplot(radf_dta_lag1, wb, option = "sadf"), regexp = NA)
   })
 )
 
-index(radf_dta) <- seq(as.Date("1991/10/01"), by = "month", length.out = 100)
+index(radf_dta) <- seq(from = as.Date("1991/10/01"),
+                       by = "month", length.out = 100)
 
 withr::with_options(
   c(warn = 2),
@@ -129,10 +132,9 @@ withr::with_options(
   c(warn = 2),
   test_that("no problem running summary (date, wb)", {
     expect_error(datestamp(radf_dta, wb), regexp = NA)
-    msg <- "'sadf' applies onyl to MC critical values"
-    expect_error(datestamp(radf_dta, wb, option = "sadf"), msg)
+    expect_error(datestamp(radf_dta, wb, option = "sadf"), regexp = NA)
     expect_error(autoplot(radf_dta, wb), regexp = NA)
-    expect_error(autoplot(radf_dta, wb, option = "sadf"), msg)
+    expect_error(autoplot(radf_dta, wb, option = "sadf"), regexp = NA)
   })
 )
 
@@ -140,7 +142,6 @@ withr::with_options(
   c(warn = 2),
   test_that("no problem running summary (date, lag, wb)", {
     expect_error(datestamp(radf_dta_lag1, wb), regexp = NA)
-    msg <- "'sadf' applies onyl to MC critical values"
-    expect_error(datestamp(radf_dta_lag1, wb, option = "sadf"), msg)
+    expect_error(datestamp(radf_dta_lag1, wb, option = "sadf"), regexp = NA)
   })
 )
